##
##  age.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_age_base  1.2.0
%define       V_age_snap  20240616

#   package information
Name:         age
Summary:      Public-Key Cryptography Tool
URL:          https://github.com/FiloSottile/age
Vendor:       Google
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Cryptography
License:      BSD
Version:      %{V_age_base}.%{V_age_snap}
Release:      20240616

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/age/age-%{V_age_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    A simple, modern and secure encryption tool with small explicit
    keys, no config options, and Unix-style composability.

%track
    prog age = {
        version   = %{V_age_base}
        url       = https://github.com/FiloSottile/age/releases
        regex     = tree/v(\d+\.\d+\.\d+)
    }

%prep
    %setup -q -n age

%build
    #   build program
    (   export GOPATH=`pwd`
        cd $GOPATH/src/github.com/FiloSottile/age
        go build -v -o age cmd/age/*.go
        go build -v -o age-keygen cmd/age-keygen/*.go
    ) || exit $?

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/FiloSottile/age/age \
        src/github.com/FiloSottile/age/age-keygen \
        $RPM_BUILD_ROOT%{l_prefix}/bin/

    #   install manual page
    %{l_shtool} install -c -m 644 \
        src/github.com/FiloSottile/age/doc/age.1 \
        src/github.com/FiloSottile/age/doc/age-keygen.1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

